==> kubernetes-model-apiextensions-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceDefinitionVersionFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface CustomResourceDefinitionVersionFluent<A extends io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToAdditionalPrinterColumns(java.lang.Integer index,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition item);
  public A setToAdditionalPrinterColumns(java.lang.Integer index,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition item);
  public A addToAdditionalPrinterColumns(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition... items);
  public A addAllToAdditionalPrinterColumns(java.util.Collection<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition> items);
  public A removeFromAdditionalPrinterColumns(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition... items);
  public A removeAllFromAdditionalPrinterColumns(java.util.Collection<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition> items);
  public A removeMatchingFromAdditionalPrinterColumns(java.util.function.Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinitionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildAdditionalPrinterColumns instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition> getAdditionalPrinterColumns();
  public java.util.List<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition> buildAdditionalPrinterColumns();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition buildAdditionalPrinterColumn(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition buildFirstAdditionalPrinterColumn();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition buildLastAdditionalPrinterColumn();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition buildMatchingAdditionalPrinterColumn(java.util.function.Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinitionBuilder> predicate);
  public java.lang.Boolean hasMatchingAdditionalPrinterColumn(java.util.function.Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinitionBuilder> predicate);
  public A withAdditionalPrinterColumns(java.util.List<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition> additionalPrinterColumns);
  public A withAdditionalPrinterColumns(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition... additionalPrinterColumns);
  public java.lang.Boolean hasAdditionalPrinterColumns();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> addNewAdditionalPrinterColumn();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> addNewAdditionalPrinterColumnLike(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition item);
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> setNewAdditionalPrinterColumnLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition item);
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> editAdditionalPrinterColumn(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> editFirstAdditionalPrinterColumn();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> editLastAdditionalPrinterColumn();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> editMatchingAdditionalPrinterColumn(java.util.function.Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinitionBuilder> predicate);
  public java.lang.Boolean getDeprecated();
  public A withDeprecated(java.lang.Boolean deprecated);
  public java.lang.Boolean hasDeprecated();
  public java.lang.String getDeprecationWarning();
  public A withDeprecationWarning(java.lang.String deprecationWarning);
  public java.lang.Boolean hasDeprecationWarning();
  
  /**
   * Method is deprecated. use withDeprecationWarning instead.
   */
  @java.lang.Deprecated
  public A withNewDeprecationWarning(java.lang.String arg0);
  public java.lang.String getName();
  public A withName(java.lang.String name);
  public java.lang.Boolean hasName();
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildSchema instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceValidation getSchema();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceValidation buildSchema();
  public A withSchema(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceValidation schema);
  public java.lang.Boolean hasSchema();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.SchemaNested<A> withNewSchema();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.SchemaNested<A> withNewSchemaLike(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceValidation item);
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.SchemaNested<A> editSchema();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.SchemaNested<A> editOrNewSchema();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.SchemaNested<A> editOrNewSchemaLike(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceValidation item);
  public java.lang.Boolean getServed();
  public A withServed(java.lang.Boolean served);
  public java.lang.Boolean hasServed();
  public java.lang.Boolean getStorage();
  public A withStorage(java.lang.Boolean storage);
  public java.lang.Boolean hasStorage();
  
  /**
   * This method has been deprecated, please use method buildSubresources instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresources getSubresources();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresources buildSubresources();
  public A withSubresources(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresources subresources);
  public java.lang.Boolean hasSubresources();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.SubresourcesNested<A> withNewSubresources();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.SubresourcesNested<A> withNewSubresourcesLike(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresources item);
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.SubresourcesNested<A> editSubresources();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.SubresourcesNested<A> editOrNewSubresources();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.SubresourcesNested<A> editOrNewSubresourcesLike(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresources item);
  public interface AdditionalPrinterColumnsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinitionFluent<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<N>>{
    public N and();
    public N endAdditionalPrinterColumn();
    
  }
  public interface SchemaNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceValidationFluent<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.SchemaNested<N>>{
    public N and();
    public N endSchema();
    
  }
  public interface SubresourcesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.SubresourcesNested<N>>{
    public N and();
    public N endSubresources();
    
  }
  
}

==> kubernetes-model-apiextensions-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceDefinitionVersionFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface CustomResourceDefinitionVersionFluent<A extends io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToAdditionalPrinterColumns(java.lang.Integer index,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition item);
  public A setToAdditionalPrinterColumns(java.lang.Integer index,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition item);
  public A addToAdditionalPrinterColumns(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition... items);
  public A addAllToAdditionalPrinterColumns(java.util.Collection<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition> items);
  public A removeFromAdditionalPrinterColumns(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition... items);
  public A removeAllFromAdditionalPrinterColumns(java.util.Collection<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition> items);
  public A removeMatchingFromAdditionalPrinterColumns(java.util.function.Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinitionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildAdditionalPrinterColumns instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition> getAdditionalPrinterColumns();
  public java.util.List<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition> buildAdditionalPrinterColumns();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition buildAdditionalPrinterColumn(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition buildFirstAdditionalPrinterColumn();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition buildLastAdditionalPrinterColumn();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition buildMatchingAdditionalPrinterColumn(java.util.function.Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinitionBuilder> predicate);
  public java.lang.Boolean hasMatchingAdditionalPrinterColumn(java.util.function.Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinitionBuilder> predicate);
  public A withAdditionalPrinterColumns(java.util.List<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition> additionalPrinterColumns);
  public A withAdditionalPrinterColumns(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition... additionalPrinterColumns);
  public java.lang.Boolean hasAdditionalPrinterColumns();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> addNewAdditionalPrinterColumn();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> addNewAdditionalPrinterColumnLike(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition item);
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> setNewAdditionalPrinterColumnLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition item);
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> editAdditionalPrinterColumn(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> editFirstAdditionalPrinterColumn();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> editLastAdditionalPrinterColumn();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> editMatchingAdditionalPrinterColumn(java.util.function.Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinitionBuilder> predicate);
  public java.lang.Boolean getDeprecated();
  public A withDeprecated(java.lang.Boolean deprecated);
  public java.lang.Boolean hasDeprecated();
  public java.lang.String getDeprecationWarning();
  public A withDeprecationWarning(java.lang.String deprecationWarning);
  public java.lang.Boolean hasDeprecationWarning();
  
  /**
   * Method is deprecated. use withDeprecationWarning instead.
   */
  @java.lang.Deprecated
  public A withNewDeprecationWarning(java.lang.String arg0);
  public java.lang.String getName();
  public A withName(java.lang.String name);
  public java.lang.Boolean hasName();
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildSchema instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceValidation getSchema();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceValidation buildSchema();
  public A withSchema(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceValidation schema);
  public java.lang.Boolean hasSchema();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.SchemaNested<A> withNewSchema();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.SchemaNested<A> withNewSchemaLike(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceValidation item);
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.SchemaNested<A> editSchema();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.SchemaNested<A> editOrNewSchema();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.SchemaNested<A> editOrNewSchemaLike(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceValidation item);
  public java.lang.Boolean getServed();
  public A withServed(java.lang.Boolean served);
  public java.lang.Boolean hasServed();
  public java.lang.Boolean getStorage();
  public A withStorage(java.lang.Boolean storage);
  public java.lang.Boolean hasStorage();
  
  /**
   * This method has been deprecated, please use method buildSubresources instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresources getSubresources();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresources buildSubresources();
  public A withSubresources(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresources subresources);
  public java.lang.Boolean hasSubresources();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.SubresourcesNested<A> withNewSubresources();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.SubresourcesNested<A> withNewSubresourcesLike(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresources item);
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.SubresourcesNested<A> editSubresources();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.SubresourcesNested<A> editOrNewSubresources();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.SubresourcesNested<A> editOrNewSubresourcesLike(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresources item);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface AdditionalPrinterColumnsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinitionFluent<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<N>>{
    public N and();
    public N endAdditionalPrinterColumn();
    
  }
  public interface SchemaNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceValidationFluent<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.SchemaNested<N>>{
    public N and();
    public N endSchema();
    
  }
  public interface SubresourcesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionVersionFluent.SubresourcesNested<N>>{
    public N and();
    public N endSubresources();
    
  }
  
}
